==> sdbus-cpp-doc-1.3.0-1-aarch64.pkg.tar.xz: usr/share/doc/sdbus-c++/html/annotated_dup.js <==
var annotated_dup =
[
    [ "sdbus", null, [
      [ "AdaptorInterfaces", "classsdbus_1_1AdaptorInterfaces.html", "classsdbus_1_1AdaptorInterfaces" ],
      [ "adopt_fd_t", "structsdbus_1_1adopt__fd__t.html", null ],
      [ "adopt_message_t", "structsdbus_1_1adopt__message__t.html", null ],
      [ "aggregate_signature", "structsdbus_1_1aggregate__signature.html", null ],
      [ "aggregate_signature< std::tuple< _Types... > >", "structsdbus_1_1aggregate__signature_3_01std_1_1tuple_3_01__Types_8_8_8_01_4_01_4.html", null ],
      [ "AsyncMethodInvoker", "classsdbus_1_1AsyncMethodInvoker.html", null ],
      [ "dont_request_slot_t", "structsdbus_1_1dont__request__slot__t.html", null ],
      [ "dont_run_event_loop_thread_t", "structsdbus_1_1dont__run__event__loop__thread__t.html", null ],
      [ "Error", "classsdbus_1_1Error.html", null ],
      [ "Flags", "classsdbus_1_1Flags.html", null ],
      [ "floating_slot_t", "structsdbus_1_1floating__slot__t.html", null ],
      [ "function_traits", "structsdbus_1_1function__traits.html", null ],
      [ "function_traits< _ReturnType(*)(_Args...)>", "structsdbus_1_1function__traits_3_01__ReturnType_07_5_08_07__Args_8_8_8_08_4.html", null ],
      [ "function_traits< _ReturnType(_Args...)>", "structsdbus_1_1function__traits_3_01__ReturnType_07__Args_8_8_8_08_4.html", null ],
      [ "function_traits< _ReturnType(_ClassType::*)(_Args...) const >", "structsdbus_1_1function__traits_3_01__ReturnType_07__ClassType_1_1_5_08_07__Args_8_8_8_08_01const_01_4.html", null ],
      [ "function_traits< _ReturnType(_ClassType::*)(_Args...) const volatile >", "structsdbus_1_1function__traits_3_01__ReturnType_07__ClassType_1_1_5_08_07__Args_8_8_8_08_01const_01volatile_01_4.html", null ],
      [ "function_traits< _ReturnType(_ClassType::*)(_Args...) volatile >", "structsdbus_1_1function__traits_3_01__ReturnType_07__ClassType_1_1_5_08_07__Args_8_8_8_08_01volatile_01_4.html", null ],
      [ "function_traits< _ReturnType(_ClassType::*)(_Args...)>", "structsdbus_1_1function__traits_3_01__ReturnType_07__ClassType_1_1_5_08_07__Args_8_8_8_08_4.html", null ],
      [ "function_traits< _Type & >", "structsdbus_1_1function__traits_3_01__Type_01_6_01_4.html", null ],
      [ "function_traits< const _Type >", "structsdbus_1_1function__traits_3_01const_01__Type_01_4.html", null ],
      [ "function_traits< std::function< FunctionType > >", "structsdbus_1_1function__traits_3_01std_1_1function_3_01FunctionType_01_4_01_4.html", null ],
      [ "function_traits< void(const Error *, _Args...)>", "structsdbus_1_1function__traits_3_01void_07const_01Error_01_5_00_01__Args_8_8_8_08_4.html", null ],
      [ "function_traits< void(Result< _Results... > &&, _Args...)>", "structsdbus_1_1function__traits_3_01void_07Result_3_01__Results_8_8_8_01_4_01_6_6_00_01__Args_8_8_8_08_4.html", null ],
      [ "function_traits< void(Result< _Results... >, _Args...)>", "structsdbus_1_1function__traits_3_01void_07Result_3_01__Results_8_8_8_01_4_00_01__Args_8_8_8_08_4.html", null ],
      [ "function_traits_base", "structsdbus_1_1function__traits__base.html", "structsdbus_1_1function__traits__base" ],
      [ "future_return", "structsdbus_1_1future__return.html", null ],
      [ "future_return< _Type >", "structsdbus_1_1future__return_3_01__Type_01_4.html", null ],
      [ "future_return<>", "structsdbus_1_1future__return_3_4.html", null ],
      [ "IConnection", "classsdbus_1_1IConnection.html", "classsdbus_1_1IConnection" ],
      [ "InterfaceFlagsSetter", "classsdbus_1_1InterfaceFlagsSetter.html", null ],
      [ "Introspectable_proxy", "classsdbus_1_1Introspectable__proxy.html", null ],
      [ "IObject", "classsdbus_1_1IObject.html", "classsdbus_1_1IObject" ],
      [ "IProxy", "classsdbus_1_1IProxy.html", "classsdbus_1_1IProxy" ],
      [ "ManagedObject_adaptor", "classsdbus_1_1ManagedObject__adaptor.html", "classsdbus_1_1ManagedObject__adaptor" ],
      [ "Message", "classsdbus_1_1Message.html", null ],
      [ "MethodCall", "classsdbus_1_1MethodCall.html", null ],
      [ "MethodInvoker", "classsdbus_1_1MethodInvoker.html", null ],
      [ "MethodRegistrator", "classsdbus_1_1MethodRegistrator.html", null ],
      [ "MethodReply", "classsdbus_1_1MethodReply.html", null ],
      [ "ObjectHolder", "classsdbus_1_1ObjectHolder.html", null ],
      [ "ObjectManager_adaptor", "classsdbus_1_1ObjectManager__adaptor.html", null ],
      [ "ObjectManager_proxy", "classsdbus_1_1ObjectManager__proxy.html", null ],
      [ "ObjectPath", "classsdbus_1_1ObjectPath.html", null ],
      [ "Peer_proxy", "classsdbus_1_1Peer__proxy.html", null ],
      [ "PendingAsyncCall", "classsdbus_1_1PendingAsyncCall.html", "classsdbus_1_1PendingAsyncCall" ],
      [ "PlainMessage", "classsdbus_1_1PlainMessage.html", null ],
      [ "Properties_adaptor", "classsdbus_1_1Properties__adaptor.html", null ],
      [ "Properties_proxy", "classsdbus_1_1Properties__proxy.html", null ],
      [ "PropertyGetReply", "classsdbus_1_1PropertyGetReply.html", null ],
      [ "PropertyGetter", "classsdbus_1_1PropertyGetter.html", null ],
      [ "PropertyRegistrator", "classsdbus_1_1PropertyRegistrator.html", null ],
      [ "PropertySetCall", "classsdbus_1_1PropertySetCall.html", null ],
      [ "PropertySetter", "classsdbus_1_1PropertySetter.html", null ],
      [ "ProxyInterfaces", "classsdbus_1_1ProxyInterfaces.html", "classsdbus_1_1ProxyInterfaces" ],
      [ "ProxyObjectHolder", "classsdbus_1_1ProxyObjectHolder.html", null ],
      [ "request_slot_t", "structsdbus_1_1request__slot__t.html", null ],
      [ "Result", "classsdbus_1_1Result.html", null ],
      [ "Signal", "classsdbus_1_1Signal.html", null ],
      [ "SignalEmitter", "classsdbus_1_1SignalEmitter.html", null ],
      [ "SignalRegistrator", "classsdbus_1_1SignalRegistrator.html", null ],
      [ "SignalSubscriber", "classsdbus_1_1SignalSubscriber.html", null ],
      [ "SignalUnsubscriber", "classsdbus_1_1SignalUnsubscriber.html", null ],
      [ "Signature", "classsdbus_1_1Signature.html", null ],
      [ "signature_of", "structsdbus_1_1signature__of.html", null ],
      [ "signature_of< _T & >", "structsdbus_1_1signature__of_3_01__T_01_6_01_4.html", null ],
      [ "signature_of< bool >", "structsdbus_1_1signature__of_3_01bool_01_4.html", null ],
      [ "signature_of< char * >", "structsdbus_1_1signature__of_3_01char_01_5_01_4.html", null ],
      [ "signature_of< char[_N]>", "structsdbus_1_1signature__of_3_01char_0f__N_0e_4.html", null ],
      [ "signature_of< const _T >", "structsdbus_1_1signature__of_3_01const_01__T_01_4.html", null ],
      [ "signature_of< const char * >", "structsdbus_1_1signature__of_3_01const_01char_01_5_01_4.html", null ],
      [ "signature_of< const char[_N]>", "structsdbus_1_1signature__of_3_01const_01char_0f__N_0e_4.html", null ],
      [ "signature_of< double >", "structsdbus_1_1signature__of_3_01double_01_4.html", null ],
      [ "signature_of< int16_t >", "structsdbus_1_1signature__of_3_01int16__t_01_4.html", null ],
      [ "signature_of< int32_t >", "structsdbus_1_1signature__of_3_01int32__t_01_4.html", null ],
      [ "signature_of< int64_t >", "structsdbus_1_1signature__of_3_01int64__t_01_4.html", null ],
      [ "signature_of< ObjectPath >", "structsdbus_1_1signature__of_3_01ObjectPath_01_4.html", null ],
      [ "signature_of< Signature >", "structsdbus_1_1signature__of_3_01Signature_01_4.html", null ],
      [ "signature_of< std::array< _Element, _Size > >", "structsdbus_1_1signature__of_3_01std_1_1array_3_01__Element_00_01__Size_01_4_01_4.html", null ],
      [ "signature_of< std::map< _Key, _Value, _Compare, _Allocator > >", "structsdbus_1_1signature__of_3_01std_1_1map_3_01__Key_00_01__Value_00_01__Compare_00_01__Allocator_01_4_01_4.html", null ],
      [ "signature_of< std::string >", "structsdbus_1_1signature__of_3_01std_1_1string_01_4.html", null ],
      [ "signature_of< std::unordered_map< _Key, _Value, _Hash, _KeyEqual, _Allocator > >", "structsdbus_1_1signature__of_3_01std_1_1unordered__map_3_01__Key_00_01__Value_00_01__Hash_00_01_40048d72e250466c6428c038be9a5369.html", null ],
      [ "signature_of< std::vector< _Element, _Allocator > >", "structsdbus_1_1signature__of_3_01std_1_1vector_3_01__Element_00_01__Allocator_01_4_01_4.html", null ],
      [ "signature_of< Struct< _ValueTypes... > >", "structsdbus_1_1signature__of_3_01Struct_3_01__ValueTypes_8_8_8_01_4_01_4.html", null ],
      [ "signature_of< uint16_t >", "structsdbus_1_1signature__of_3_01uint16__t_01_4.html", null ],
      [ "signature_of< uint32_t >", "structsdbus_1_1signature__of_3_01uint32__t_01_4.html", null ],
      [ "signature_of< uint64_t >", "structsdbus_1_1signature__of_3_01uint64__t_01_4.html", null ],
      [ "signature_of< uint8_t >", "structsdbus_1_1signature__of_3_01uint8__t_01_4.html", null ],
      [ "signature_of< UnixFd >", "structsdbus_1_1signature__of_3_01UnixFd_01_4.html", null ],
      [ "signature_of< Variant >", "structsdbus_1_1signature__of_3_01Variant_01_4.html", null ],
      [ "signature_of< void >", "structsdbus_1_1signature__of_3_01void_01_4.html", null ],
      [ "signature_of_function_input_arguments", "structsdbus_1_1signature__of__function__input__arguments.html", null ],
      [ "signature_of_function_output_arguments", "structsdbus_1_1signature__of__function__output__arguments.html", null ],
      [ "Struct", "classsdbus_1_1Struct.html", null ],
      [ "tuple_of_function_input_arg_types", "structsdbus_1_1tuple__of__function__input__arg__types.html", null ],
      [ "tuple_of_function_output_arg_types", "structsdbus_1_1tuple__of__function__output__arg__types.html", null ],
      [ "UnixFd", "classsdbus_1_1UnixFd.html", null ],
      [ "Variant", "classsdbus_1_1Variant.html", null ],
      [ "with_future_t", "structsdbus_1_1with__future__t.html", null ]
    ] ],
    [ "std", null, [
      [ "tuple_element< _I, sdbus::Struct< _ValueTypes... > >", "structstd_1_1tuple__element_3_01__I_00_01sdbus_1_1Struct_3_01__ValueTypes_8_8_8_01_4_01_4.html", null ],
      [ "tuple_size< sdbus::Struct< _ValueTypes... > >", "structstd_1_1tuple__size_3_01sdbus_1_1Struct_3_01__ValueTypes_8_8_8_01_4_01_4.html", null ]
    ] ]
];

==> sdbus-cpp-doc-1.4.0-1-aarch64.pkg.tar.xz: usr/share/doc/sdbus-c++/html/annotated_dup.js <==
var annotated_dup =
[
    [ "sdbus", null, [
      [ "AdaptorInterfaces", "classsdbus_1_1AdaptorInterfaces.html", "classsdbus_1_1AdaptorInterfaces" ],
      [ "adopt_fd_t", "structsdbus_1_1adopt__fd__t.html", null ],
      [ "adopt_message_t", "structsdbus_1_1adopt__message__t.html", null ],
      [ "aggregate_signature", "structsdbus_1_1aggregate__signature.html", null ],
      [ "aggregate_signature< std::tuple< _Types... > >", "structsdbus_1_1aggregate__signature_3_01std_1_1tuple_3_01__Types_8_8_8_01_4_01_4.html", null ],
      [ "AllPropertiesGetter", "classsdbus_1_1AllPropertiesGetter.html", null ],
      [ "AsyncAllPropertiesGetter", "classsdbus_1_1AsyncAllPropertiesGetter.html", null ],
      [ "AsyncMethodInvoker", "classsdbus_1_1AsyncMethodInvoker.html", null ],
      [ "AsyncPropertyGetter", "classsdbus_1_1AsyncPropertyGetter.html", null ],
      [ "AsyncPropertySetter", "classsdbus_1_1AsyncPropertySetter.html", null ],
      [ "dont_expect_reply_t", "structsdbus_1_1dont__expect__reply__t.html", null ],
      [ "dont_request_slot_t", "structsdbus_1_1dont__request__slot__t.html", null ],
      [ "dont_run_event_loop_thread_t", "structsdbus_1_1dont__run__event__loop__thread__t.html", null ],
      [ "Error", "classsdbus_1_1Error.html", null ],
      [ "Flags", "classsdbus_1_1Flags.html", null ],
      [ "floating_slot_t", "structsdbus_1_1floating__slot__t.html", null ],
      [ "function_traits", "structsdbus_1_1function__traits.html", null ],
      [ "function_traits< _ReturnType(*)(_Args...)>", "structsdbus_1_1function__traits_3_01__ReturnType_07_5_08_07__Args_8_8_8_08_4.html", null ],
      [ "function_traits< _ReturnType(_Args...)>", "structsdbus_1_1function__traits_3_01__ReturnType_07__Args_8_8_8_08_4.html", null ],
      [ "function_traits< _ReturnType(_ClassType::*)(_Args...) const >", "structsdbus_1_1function__traits_3_01__ReturnType_07__ClassType_1_1_5_08_07__Args_8_8_8_08_01const_01_4.html", null ],
      [ "function_traits< _ReturnType(_ClassType::*)(_Args...) const volatile >", "structsdbus_1_1function__traits_3_01__ReturnType_07__ClassType_1_1_5_08_07__Args_8_8_8_08_01const_01volatile_01_4.html", null ],
      [ "function_traits< _ReturnType(_ClassType::*)(_Args...) volatile >", "structsdbus_1_1function__traits_3_01__ReturnType_07__ClassType_1_1_5_08_07__Args_8_8_8_08_01volatile_01_4.html", null ],
      [ "function_traits< _ReturnType(_ClassType::*)(_Args...)>", "structsdbus_1_1function__traits_3_01__ReturnType_07__ClassType_1_1_5_08_07__Args_8_8_8_08_4.html", null ],
      [ "function_traits< _Type & >", "structsdbus_1_1function__traits_3_01__Type_01_6_01_4.html", null ],
      [ "function_traits< const _Type >", "structsdbus_1_1function__traits_3_01const_01__Type_01_4.html", null ],
      [ "function_traits< std::function< FunctionType > >", "structsdbus_1_1function__traits_3_01std_1_1function_3_01FunctionType_01_4_01_4.html", null ],
      [ "function_traits< void(const Error *, _Args...)>", "structsdbus_1_1function__traits_3_01void_07const_01Error_01_5_00_01__Args_8_8_8_08_4.html", null ],
      [ "function_traits< void(Result< _Results... > &&, _Args...)>", "structsdbus_1_1function__traits_3_01void_07Result_3_01__Results_8_8_8_01_4_01_6_6_00_01__Args_8_8_8_08_4.html", null ],
      [ "function_traits< void(Result< _Results... >, _Args...)>", "structsdbus_1_1function__traits_3_01void_07Result_3_01__Results_8_8_8_01_4_00_01__Args_8_8_8_08_4.html", null ],
      [ "function_traits_base", "structsdbus_1_1function__traits__base.html", "structsdbus_1_1function__traits__base" ],
      [ "future_return", "structsdbus_1_1future__return.html", null ],
      [ "future_return< _Type >", "structsdbus_1_1future__return_3_01__Type_01_4.html", null ],
      [ "future_return<>", "structsdbus_1_1future__return_3_4.html", null ],
      [ "IConnection", "classsdbus_1_1IConnection.html", "classsdbus_1_1IConnection" ],
      [ "InterfaceFlagsSetter", "classsdbus_1_1InterfaceFlagsSetter.html", null ],
      [ "Introspectable_proxy", "classsdbus_1_1Introspectable__proxy.html", null ],
      [ "IObject", "classsdbus_1_1IObject.html", "classsdbus_1_1IObject" ],
      [ "IProxy", "classsdbus_1_1IProxy.html", "classsdbus_1_1IProxy" ],
      [ "ManagedObject_adaptor", "classsdbus_1_1ManagedObject__adaptor.html", "classsdbus_1_1ManagedObject__adaptor" ],
      [ "Message", "classsdbus_1_1Message.html", null ],
      [ "MethodCall", "classsdbus_1_1MethodCall.html", null ],
      [ "MethodInvoker", "classsdbus_1_1MethodInvoker.html", null ],
      [ "MethodRegistrator", "classsdbus_1_1MethodRegistrator.html", null ],
      [ "MethodReply", "classsdbus_1_1MethodReply.html", null ],
      [ "ObjectHolder", "classsdbus_1_1ObjectHolder.html", null ],
      [ "ObjectManager_adaptor", "classsdbus_1_1ObjectManager__adaptor.html", null ],
      [ "ObjectManager_proxy", "classsdbus_1_1ObjectManager__proxy.html", null ],
      [ "ObjectPath", "classsdbus_1_1ObjectPath.html", null ],
      [ "Peer_proxy", "classsdbus_1_1Peer__proxy.html", null ],
      [ "PendingAsyncCall", "classsdbus_1_1PendingAsyncCall.html", "classsdbus_1_1PendingAsyncCall" ],
      [ "PlainMessage", "classsdbus_1_1PlainMessage.html", null ],
      [ "Properties_adaptor", "classsdbus_1_1Properties__adaptor.html", null ],
      [ "Properties_proxy", "classsdbus_1_1Properties__proxy.html", null ],
      [ "PropertyGetReply", "classsdbus_1_1PropertyGetReply.html", null ],
      [ "PropertyGetter", "classsdbus_1_1PropertyGetter.html", null ],
      [ "PropertyRegistrator", "classsdbus_1_1PropertyRegistrator.html", null ],
      [ "PropertySetCall", "classsdbus_1_1PropertySetCall.html", null ],
      [ "PropertySetter", "classsdbus_1_1PropertySetter.html", null ],
      [ "ProxyInterfaces", "classsdbus_1_1ProxyInterfaces.html", "classsdbus_1_1ProxyInterfaces" ],
      [ "ProxyObjectHolder", "classsdbus_1_1ProxyObjectHolder.html", null ],
      [ "request_slot_t", "structsdbus_1_1request__slot__t.html", null ],
      [ "Result", "classsdbus_1_1Result.html", null ],
      [ "Signal", "classsdbus_1_1Signal.html", null ],
      [ "SignalEmitter", "classsdbus_1_1SignalEmitter.html", null ],
      [ "SignalRegistrator", "classsdbus_1_1SignalRegistrator.html", null ],
      [ "SignalSubscriber", "classsdbus_1_1SignalSubscriber.html", null ],
      [ "SignalUnsubscriber", "classsdbus_1_1SignalUnsubscriber.html", null ],
      [ "Signature", "classsdbus_1_1Signature.html", null ],
      [ "signature_of", "structsdbus_1_1signature__of.html", null ],
      [ "signature_of< _T & >", "structsdbus_1_1signature__of_3_01__T_01_6_01_4.html", null ],
      [ "signature_of< bool >", "structsdbus_1_1signature__of_3_01bool_01_4.html", null ],
      [ "signature_of< char * >", "structsdbus_1_1signature__of_3_01char_01_5_01_4.html", null ],
      [ "signature_of< char[_N]>", "structsdbus_1_1signature__of_3_01char_0f__N_0e_4.html", null ],
      [ "signature_of< const _T >", "structsdbus_1_1signature__of_3_01const_01__T_01_4.html", null ],
      [ "signature_of< const char * >", "structsdbus_1_1signature__of_3_01const_01char_01_5_01_4.html", null ],
      [ "signature_of< const char[_N]>", "structsdbus_1_1signature__of_3_01const_01char_0f__N_0e_4.html", null ],
      [ "signature_of< double >", "structsdbus_1_1signature__of_3_01double_01_4.html", null ],
      [ "signature_of< int16_t >", "structsdbus_1_1signature__of_3_01int16__t_01_4.html", null ],
      [ "signature_of< int32_t >", "structsdbus_1_1signature__of_3_01int32__t_01_4.html", null ],
      [ "signature_of< int64_t >", "structsdbus_1_1signature__of_3_01int64__t_01_4.html", null ],
      [ "signature_of< ObjectPath >", "structsdbus_1_1signature__of_3_01ObjectPath_01_4.html", null ],
      [ "signature_of< Signature >", "structsdbus_1_1signature__of_3_01Signature_01_4.html", null ],
      [ "signature_of< std::array< _Element, _Size > >", "structsdbus_1_1signature__of_3_01std_1_1array_3_01__Element_00_01__Size_01_4_01_4.html", null ],
      [ "signature_of< std::map< _Key, _Value, _Compare, _Allocator > >", "structsdbus_1_1signature__of_3_01std_1_1map_3_01__Key_00_01__Value_00_01__Compare_00_01__Allocator_01_4_01_4.html", null ],
      [ "signature_of< std::string >", "structsdbus_1_1signature__of_3_01std_1_1string_01_4.html", null ],
      [ "signature_of< std::unordered_map< _Key, _Value, _Hash, _KeyEqual, _Allocator > >", "structsdbus_1_1signature__of_3_01std_1_1unordered__map_3_01__Key_00_01__Value_00_01__Hash_00_01_40048d72e250466c6428c038be9a5369.html", null ],
      [ "signature_of< std::vector< _Element, _Allocator > >", "structsdbus_1_1signature__of_3_01std_1_1vector_3_01__Element_00_01__Allocator_01_4_01_4.html", null ],
      [ "signature_of< Struct< _ValueTypes... > >", "structsdbus_1_1signature__of_3_01Struct_3_01__ValueTypes_8_8_8_01_4_01_4.html", null ],
      [ "signature_of< uint16_t >", "structsdbus_1_1signature__of_3_01uint16__t_01_4.html", null ],
      [ "signature_of< uint32_t >", "structsdbus_1_1signature__of_3_01uint32__t_01_4.html", null ],
      [ "signature_of< uint64_t >", "structsdbus_1_1signature__of_3_01uint64__t_01_4.html", null ],
      [ "signature_of< uint8_t >", "structsdbus_1_1signature__of_3_01uint8__t_01_4.html", null ],
      [ "signature_of< UnixFd >", "structsdbus_1_1signature__of_3_01UnixFd_01_4.html", null ],
      [ "signature_of< Variant >", "structsdbus_1_1signature__of_3_01Variant_01_4.html", null ],
      [ "signature_of< void >", "structsdbus_1_1signature__of_3_01void_01_4.html", null ],
      [ "signature_of_function_input_arguments", "structsdbus_1_1signature__of__function__input__arguments.html", null ],
      [ "signature_of_function_output_arguments", "structsdbus_1_1signature__of__function__output__arguments.html", null ],
      [ "Struct", "classsdbus_1_1Struct.html", null ],
      [ "tuple_of_function_input_arg_types", "structsdbus_1_1tuple__of__function__input__arg__types.html", null ],
      [ "tuple_of_function_output_arg_types", "structsdbus_1_1tuple__of__function__output__arg__types.html", null ],
      [ "UnixFd", "classsdbus_1_1UnixFd.html", null ],
      [ "Variant", "classsdbus_1_1Variant.html", null ],
      [ "with_future_t", "structsdbus_1_1with__future__t.html", null ]
    ] ],
    [ "std", null, [
      [ "tuple_element< _I, sdbus::Struct< _ValueTypes... > >", "structstd_1_1tuple__element_3_01__I_00_01sdbus_1_1Struct_3_01__ValueTypes_8_8_8_01_4_01_4.html", null ],
      [ "tuple_size< sdbus::Struct< _ValueTypes... > >", "structstd_1_1tuple__size_3_01sdbus_1_1Struct_3_01__ValueTypes_8_8_8_01_4_01_4.html", null ]
    ] ]
];
